@@ -133,6 +133,11 @@ void Playlist::nextShuffle()
     setCurrentIndex(std::rand() % count);
 }
 
+void Playlist::play(int index)
+{
+    setCurrentIndex(index);
+}
+
 void Playlist::clear()
 {
     if (!m_model)
@@ -215,6 +220,26 @@ void Playlist::setCurrentIndex(int index)
     emit currentTrackChanged(m_currentTrack);
 }
 
+void Playlist::changeCurrentIndex(int index)
+{
+    if (!m_model)
+    {
+        return;
+    }
+
+    const auto count = m_model->getCount();
+    if (count > 0 && index < count && index >= 0)
+    {
+        m_currentIndex = index;
+    } else
+    {
+        return;
+    }
+
+    qDebug() << "changing current track index" << index << m_currentIndex;
+    emit currentIndexChanged(m_currentIndex);
+}
+
 void Playlist::setPlayMode(Playlist::PlayMode playMode)
 {
     if (m_playMode == playMode)
@@ -225,3 +250,36 @@ void Playlist::setPlayMode(Playlist::PlayMode playMode)
     emit playModeChanged(m_playMode);
 }
 
+void Playlist::move(int from, int to)
+{
+    if(!m_model)
+    {
+        return;
+    }
+
+    m_model->move(from, to);
+    if(to <= m_currentIndex)
+    {
+        changeCurrentIndex(m_currentIndex+1);
+    }
+
+    if(from <= m_currentIndex && to > m_currentIndex)
+    {
+        changeCurrentIndex(m_currentIndex-1);
+    }
+}
+
+void Playlist::remove(int index)
+{
+    if(!m_model)
+    {
+        return;
+    }
+
+    m_model->remove(index);
+    if(index <= m_currentIndex)
+    {
+        changeCurrentIndex(m_currentIndex-1);
+    }
+}
+
