@@ -12,12 +12,11 @@ class Playlist : public QObject
 
     Q_PROPERTY(TracksModel *model WRITE setModel READ model NOTIFY modelChanged)
     Q_PROPERTY(QVariantMap currentTrack READ currentTrack NOTIFY currentTrackChanged FINAL)
-    Q_PROPERTY(int currentIndex READ currentIndex WRITE setCurrentIndex NOTIFY currentIndexChanged)
+    Q_PROPERTY(int currentIndex READ currentIndex NOTIFY currentIndexChanged FINAL)
 
     Q_PROPERTY(PlayMode playMode READ playMode WRITE setPlayMode NOTIFY playModeChanged)
 
 public:
-
     enum PlayMode : uint_fast8_t
     {
         Normal,
@@ -51,6 +50,7 @@ public slots:
     void next();
     void previous();
     void nextShuffle();
+    void play(int index);
     void clear();
 
     void save();
@@ -60,9 +60,13 @@ public slots:
 
     void setModel(TracksModel *model);
     void setCurrentIndex(int index);
+    void changeCurrentIndex(int index);
 
     void setPlayMode(Playlist::PlayMode playMode);
 
+    void move(int from, int to);
+    void remove(int index);
+
 signals:
     void canPlayChanged();
     void modelChanged(TracksModel *model);
